# Becke
[![Build Status](https://dev.azure.com/yxt1991/Becke/_apis/build/status/tczorro.becke?branchName=master)](https://dev.azure.com/yxt1991/Becke/_build/latest?definitionId=3&branchName=master)
[![BSD license](https://img.shields.io/pypi/l/becke)](https://github.com/tczorro/becke/blob/master/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/becke)](https://pypi.org/project/becke/)
## About
Becke is a cython implementation of becke weights for numerical integral.

## Platform
Becke is a cython package with binary distribution on `Windows`, `Linux` and `MacOS`.

## Functionality
* Becke weights for selected atom(s) in molecule
* Becke weights for all atoms in the molecule

## License
Becke is distributed under [BSD 3-Clause](https://github.com/tczorro/becke/blob/master/LICENSE).

## Dependence
* Installation requirements: `numpy`, `cython`

## Installation
To install Becke to system:
```bash
    pip install becke
```
